COMMENT
*******************************************************************************
Procedure:    AppendMultipleFiles
Subprocedure: ImportFiles
Description:  This procedure automates the import of all files within a folder. Optionally, the procedure
              appends the files into one master file.
Requirements: Manually define the first Excel file and copy the IMPORT command to the subprocedure. Modify
              the subprocedure to use variable substitution of the v_path, v_extension, and v_filename.
              Assign the v_path, v_extension and v_CombinedFile variables at the beginning of the main procedure.
              All files must be identical in structure and stored in the same folder as referenced by the
              v_path variable. All files must have the same file extension. The folder must not contain any files
              with the same file extension that are not part of the group of files to be appended.
Note:         The IMPORT requires the worksheet name to be included. If all files have a worksheet called Sheet1, enter
              that for the table name. If not, it is easiest if the Excel file and the worksheet have the same name
              and you can use macro substitution of the v_filename variable.
Output:       A single data file with the combined records from all files named with the file name assigned to v_CombinedFile.
Written by:   Various
Modified by:  Trainer April, 2019
*******************************************************************************
END

COMMENT ** Set environment, overwrite files, set temporary object prefix, delete variables

SET DEFAULT
SET SAFETY OFF
CLOSE
SET TEMP "Temp"
DELETE ALL OK

COMMENT ** Assign variables

ASSIGN v_path = "C:\Users\janene_haddix\Desktop\IntroductoryTraining\IntroductoryTraining\SupportFiles\PayrollAnalysis\"
ASSIGN v_extension = "xlsx"
ASSIGN v_CombinedFile = "Payroll2018Combined"

COMMENT ** Creates a table of all files in the v_path folder with the extension entered.

DIR "%v_path%\*.%v_extension%" SUPPRESS TO TempFileList

COMMENT ** Open the TempFileList table

OPEN TempFileList

COMMENT ** Counts the number of records in the TempFileList table

COUNT

COMMENT ** Initialize temporary variables to track the number of files selected and their file names.

ASSIGN v_counter = COUNT1
ASSIGN v_record = 1

COMMENT **  Call the ImportFile subprocedure once for each file to be appended

DO .ImportFiles WHILE v_record <= v_counter

COMMENT ** The subprocedure returns processing to this point and the next command will open the final combined file

OPEN %v_CombinedFile%

DELETE TEMP OK

RETURN


COMMENT
***************************************************
** Subprocedure to import and append the files
END

PROCEDURE ImportFiles

OPEN TempFileList

LOCATE RECORD v_Record

v_filename = Split(FILE_NAME, ".", 1)

COMMENT ** Replace the IMPORT command with your IMPORT command **

COMMENT **          Table Name          Excel file name                  Excel Worksheet                   Data file name
IMPORT OPENEXCEL TO %v_filename% FILE "%v_path%%v_filename%.xlsx" TABLE "%v_filename%" SERVER "LOCAL" FLAT "%v_filename%.FIL" ASCII FIELDS 1 "EmployeeNo",2 "Gross_Pay",3 "Tax_Amount",4 "Net_Pay",5 "Work_Dept",6 "Pay_Date",7 "Cheque_No" END

COMMENT ** Optional extract/append all the files to one. Remove line 87 and 89 or COMMENT them out if you don't want this step executed.
COMMENT ** Extract and append all records to a new file

OPEN %v_filename%

EXTRACT FIELDS ALL TO "%v_CombinedFile%" APPEND

COMMENT ** Increase counter for next file.

ASSIGN v_record = v_record + 1

RETURN



